onTap property
void Function()?
onTap
final
Callback function invoked when the user taps on the text field.
Implementation
final void Function()? onTap;
Callback function invoked when the user taps on the text field.
final void Function()? onTap;